Authors and Contributors
========================

Authors
-------

* **Levi T. Sweet-Breu (@levisweetbreu)**
* **Em Rexer (@erexer)**
* **Chris R. Vernon (@crvernon)**
* **Melissa R. Allen-Dumas (@mallen2718)**

Contributors
------------

Additional Developers
^^^^^^^^^^^^^^^^^^^^^

* **Matthew Seals**
* **Stefan Krawczyk (@skrawcz)**
* **Elijah ben Izzy (@elijahbenizzy)**
* **Andy Berres (@q-rai)**

Product Tester
^^^^^^^^^^^^^^

* **Pouya Vahmani**

Code Formatting
^^^^^^^^^^^^^^^

* **black (`<https://black.readthedocs.io/en/stable/>`_)**
* **ruff (`<https://beta.ruff.rs/docs/>`_)**
